Tabellen invoegen en aanpassen

Tabellen invoegen en aanpassen | Inhoudsopgave

De knop 'Invoegen Tabel' stelt u in staat op de huidige plek een nieuwe tabel in uw tekst in te voegen en opent onderstaand dialoogvenster.
Omschrijving van de velden:

Kolommen | Het gewenste aantal kolommen in de tabel.
Rijen | Het gewenste aantal rijen in de tabel.
Celvulling | De 'Celvulling' (Cellpadding) De opvulmarge rondom binnen elke cel in de tabel in pixels.
Celafstand | De 'Celafstand' (Cellspacing) De ruimte tussen de cellen onderling binnen de tabel in pixels.
Positionering | De positionering van de tabel in de paragraaf.
Omranding | De dikte in pixels van de omranding van de tabel.
Breedte | De breedte van de tabel (in pixels of percentuele notatie).
Hoogte | De breedte van de tabel (in pixels of percentuele notatie).
CSS-Stijl | Optionele stijlkeuze uit de voor de website aangemaakte Cascading Style Sheet (CSS).

Ga naar: Inhoudsopgave | Naar boven